<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Chat;
use App\Models\Robot;
use Illuminate\Support\Str;
use App\Models\Conversation;
use Illuminate\Http\Request;
use Orhanerday\OpenAi\OpenAi;
use Illuminate\Support\Facades\Auth;

class RobotsController extends Controller
{
    public function robots()
    {
        $robots = Robot::with('media')->get();

        return view('robot.robots', compact('robots'));
    }

    public function conversationName(Request $request)
    {
        $conversation = Conversation::findOrFail($request->id);
        $conversation->title = $request->name;
        $conversation->save();

        return redirect()
            ->back()
            ->withSuccess(__('robots.savedSuccessfully'));
    }

    public function conversation($robot, $conversation = null)
    {
        $user = Auth::user();
        $selected_robot = Robot::findOrFail($robot);

        $robots = Robot::all();
        $conversations = Conversation::with('robot')->where('user_id', $user->id)->where('robot_id', $selected_robot->id)->get();
        if ($conversation == null) {
            $last_conversation = $conversations->last();
        } else {
            $conversation_data = $conversation == 0 ? null : Conversation::findOrFail($conversation);
            $last_conversation = $conversation_data;
        }

        $chats = Chat::where('conversation_id', $last_conversation->id ?? '')->get();

        return view('robot.conversation', compact('robots', 'conversations', 'selected_robot', 'last_conversation', 'chats'));
    }

    public function sendchat(Request $request)
    {
        $user = Auth::user();
        $new_conversation = 0;

        if ($user->remainingWords() < get_number_of_words_in_text($request->message)) {
            return response()->json(['message' => __('document.limitExceedWords'), 'success' => false]);
        }

        if ($request->conversation_id == 0) {
            $conversation = new Conversation();
            $conversation->title  = "New Conversation";
            $conversation->user_id = $user->id;
            $conversation->robot_id = $request->robot_id;
            $conversation->last_conversation_on = Carbon::now();
            $conversation->words = get_number_of_words_in_text($request->message);
            $conversation->save();

            $new_conversation = $conversation->id;
        } else {
            $conversation = Conversation::find($request->conversation_id);
            $conversation->last_conversation_on = Carbon::now();
            $conversation->words = $conversation->words + get_number_of_words_in_text($request->message);
            $conversation->save();
        }

        $userRequest = [
            'user_id' => $user->id,
            'robot_id' => 0,
            'conversation_id' => $conversation->id,
            'words' => get_number_of_words_in_text($request->message),
            'message' => htmlspecialchars($request->message)
        ];
        $chat =  Chat::create($userRequest);

        $messages = Chat::where('conversation_id', $conversation->id)->where('robot_id', 0)->get();
        $robot = Robot::find($request->robot_id);
        $open_ai_key = config('artisan.openai_api_key');

        $chat_data = [];
        foreach ($messages as $key => $message) {
            $chat_data[$key]['role'] = $message->robot_id == 0 ? 'user' : 'assistant';
            $chat_data[$key]['content'] = $message->message;
        }

        $open_ai = new OpenAi($open_ai_key);
        $open_ai->setHeader(["Connection" => "keep-alive"]);
        $chat = $open_ai->chat([
            'model' => config('artisan.openai_model', 'gpt-3.5-turbo'),
            'messages' => [
                [
                    "role" => "system",
                    "content" => $robot->command
                ],
                ...$chat_data,
                [
                    "role" => "user",
                    "content" => $request->message,
                ]
            ],
            'temperature' => 1.0,
            'frequency_penalty' => 0,
            'presence_penalty' => 0,
        ]);

        $chat = json_decode($chat, true);
        $reply_message = $chat['choices'][0]['message']['content'] ?? "";

        if (isset($chat['error'])) {
            return response()->json(['message' => $chat['error']['message'], 'success' => false]);
        }

        $botReply = [
            'robot_id' => $request->robot_id,
            'user_id' => 0,
            'conversation_id' => $conversation->id,
            'words' => get_number_of_words_in_text($reply_message),
            'message' => Str::markdown($reply_message)
        ];
        $chat =  Chat::create($botReply);
        $user->no_of_words = $user->no_of_words - (get_number_of_words_in_text($request->message) - get_number_of_words_in_text($reply_message));
        $user->save();

        $conversation->words = $conversation->words + get_number_of_words_in_text($reply_message);
        $conversation->save();

        return response()->json(['message' => $botReply['message'], 'success' => true, 'new_conversation' => $new_conversation, 'conversation' => $conversation, 'robot' => $robot, 'no_of_words' => $user->no_of_words]);
    }


    public function conversationDelete($id)
    {
        $user = Auth::user();

        $conversation = Conversation::where('user_id', $user->id)->where('id', $id)->first();

        if (!isset($conversation->id)) {
            return redirect()->back();
        }

        $robot_id = $conversation->robot_id;
        $chats = Chat::where('conversation_id', $id)->get();
        foreach ($chats as $chat) {
            $chat->delete();
        }
        $conversation->delete();

        return redirect()
            ->route('robot.conversation', ['robot' => $robot_id, 'conversation' => 0])
            ->withSuccess(__('robots.deleteSuccessfully'));
    }
}
