<x-chat-layout>
    <div class="app-body">
        <section class="chat-wrap">
            <x-robots-list :robots="$robots" :selected_robot="$selected_robot" />
            <div class="chat">
                <x-robot-chat-header :selected_robot="$selected_robot" :last_conversation="$last_conversation" />
                <x-robot-user-conversation :conversations="$conversations" :robot="$selected_robot" :last_conversation="$last_conversation" />
                <x-robot-user-chat :chats="$chats" :robot="$selected_robot" :conversation="$last_conversation" />
                <input type="hidden" name="conversation_id" value="{{ $last_conversation->id ?? 0 }}"
                    id="conversation_id" />
            </div>
        </section>
    </div>
    <div class="modal fade" id="nameModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exampleModalLabel">@lang('robots.conversationName')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="{{ route('robot.conversationName') }}" method="post">
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-md-12">
                                <label>@lang('robots.conversationName')</label>
                                <input type="text" name="name" class="form-control" required
                                    value="{{ $last_conversation->title ?? '' }}" />
                                <input type="hidden" name="id" class="form-control" required
                                    value="{{ $last_conversation->id ?? '' }}" />
                                {{ csrf_field() }}
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary"
                            data-bs-dismiss="modal">@lang('robots.close')</button>
                        <button type="submit" class="btn btn-primary">@lang('robots.save')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    @push('page_scripts')
        <script src="https://cdn.jsdelivr.net/npm/shiki"></script>
        <script>
            const APP = function() {
                let message_id = 1;
                const submit_button = document.getElementById('send');
                const message_input = document.getElementById('message-to-send');
                const sendChat = function() {
                        var message = message_input.value;
                        if (message == '' || message == null) {
                            return;
                        }
                        pushMessage(message)
                        axios.post(
                                '{{ route('robot.sendchat') }}', {
                                    robot_id: {{ $selected_robot->id }},
                                    conversation_id: document.getElementById('conversation_id').value,
                                    message: message
                                })
                            .then((res) => {
                                if (res.data.success == true) {
                                    document.getElementById(`new-message-${message_id}`).innerHTML = res.data.message
                                    if (res.data.new_conversation != 0) {
                                        document.getElementById('conversation_id').value = res.data.new_conversation;
                                        rowInsertTable(res.data.conversation, res.data.robot);
                                        window.history.pushState({}, "",
                                            `{{ route('robot.conversation', ['robot' => $selected_robot]) }}/${res.data.conversation.id}`
                                        );
                                    }
                                    document.querySelectorAll(".no-of-words span").forEach(element => {
                                        element.innerHTML = res.data.no_of_words;
                                    });
                                    message_id++;
                                } else {
                                    removeLastChild();
                                    FrontApp.toastError(res.data.message);
                                }
                                initShiki();
                                fixChatScroll();
                                enableSend();
                            })
                            .catch((err) => {
                                removeLastChild();
                                FrontApp.toastError("{{ __('common.somethingWentWrong') }}");
                                enableSend();
                            })
                    },
                    insertAfter = function(existingNode, newNode) {
                        existingNode.parentNode.insertBefore(newNode, existingNode.nextSibling);
                    },
                    initShiki = function() {
                        var codeBlock = document.querySelectorAll('pre:not(.shiki)')
                        codeBlock.forEach(function(el) {
                            var lang = el.querySelector('code').className != '' ? el.querySelector('code').className
                                .split(/[-]+/).pop() : 'bat'
                            shiki.getHighlighter({
                                theme: 'github-dark',
                                langs: [lang]
                            }).then(highlighter => {
                                var code = highlighter.codeToHtml(el.innerText, lang)
                                insertAfter(el, htmlToElement(code))
                                el.parentNode.removeChild(el)
                            });
                        })
                    },
                    enableCopy = function(node, selector = "pre", childSelector = "code", btnText =
                        "{{ __('common.copyToClipboard') }}",
                        btnTextSuccess =
                        "{{ __('common.copied') }}", activeClass = "--copy") {
                        let copyBtn = document.createElement("button");
                        copyBtn.className = 'btn btn-sm btn-outline-primary btn-copy-code'
                        copyBtn.innerText = btnText;
                        copyBtn.classList.add(activeClass);
                        copyBtn.addEventListener("click", async () => {
                            var clipboard = new ClipboardJS('.btn-copy-code', {
                                text: function() {
                                    return node.querySelector(childSelector).innerText
                                }
                            })
                            copyBtn.innerText = btnTextSuccess;
                            setTimeout(() => copyBtn.innerText = btnText, 2000);
                        })
                        node.appendChild(copyBtn);
                    },
                    htmlToElement = function(htmlString) {
                        var container = document.createElement('div');
                        container.innerHTML = htmlString;

                        var element = container.firstElementChild;
                        enableCopy(element)

                        return element;
                    },
                    pushMessage = function(message) {
                        message = `<li class="clearfix">
                                    <div class="message-data text-end">
                                        <span class="data-time small">${new Date().chatTime()}</span>
                                        <span class="name">{{ Auth::user()->name }}</span>
                                    </div>
                                    <div class="message other-message float-end">
                                        ${escapeHTML(message)}
                                    </div>
                                </li>
                                <li>
                                    <div class="message-data">
                                        <span class="name">{{ $selected_robot->name }}</span>
                                        <span class="data-time small">${new Date().chatTime()}</span>
                                    </div>
                                    <div class="message my-message" id="new-message-${message_id}">
                                        <div class="loader">
                                            <span></span>
                                            <span></span>
                                            <span></span>
                                        </div>
                                    </div>
                                </li>`;

                        disbaleSend();
                        document.getElementById('chat-list').innerHTML += message;
                        document.getElementById('message-to-send').value = "";
                        fixChatScroll()
                    },
                    escapeHTML = function(unsafe) {
                        return unsafe
                            .replace(/&/g, "&amp;")
                            .replace(/</g, "&lt;")
                            .replace(/>/g, "&gt;")
                            .replace(/"/g, "&quot;")
                            .replace(/'/g, "&#039;")
                            .replace(/(?:\r\n|\r|\n)/g, '<br>');
                    },
                    fixChatScroll = function() {
                        document.querySelector('.chat-history').scrollTo({
                            top: document.querySelector('.chat-history ul').clientHeight,
                            behavior: 'smooth'
                        });
                    },
                    removeLastChild = function() {
                        document.getElementById('chat-list').removeChild(document.getElementById('chat-list')
                            .lastElementChild);
                    },
                    disbaleSend = function() {
                        submit_button.disabled = true;
                    },
                    enableSend = function() {
                        submit_button.disabled = false;
                    },
                    rowInsertTable = function(conversation, robot) {
                        var table = document.getElementById("conversation-table");
                        var row = table.insertRow();
                        var cell1 = row.insertCell(0);
                        var cell2 = row.insertCell(1);
                        var cell3 = row.insertCell(2);
                        var cell4 = row.insertCell(3);
                        var cell5 = row.insertCell(4);
                        cell1.innerHTML = `<i class="an an-file-alt"></i>`;
                        cell2.innerHTML = conversation.title;
                        cell3.innerHTML = conversation.words;
                        cell4.innerHTML = robot.name;
                        cell5.innerHTML = conversation.last_conversation_on;
                    },
                    searchFilter = function() {
                        var input, filter, ul, li, a, i, txtValue;
                        input = document.getElementById("search-input");
                        filter = input.value.toUpperCase();
                        li = document.getElementsByClassName("robot-search-li");
                        for (i = 0; i < li.length; i++) {
                            a = li[i];
                            txtValue = a.textContent || a.innerText;
                            if (txtValue.toUpperCase().indexOf(filter) > -1) {
                                li[i].style.display = "";
                            } else {
                                li[i].style.display = "none";
                            }
                        }
                    },
                    searchFilterConversation = function() {
                        var input, filter, ul, li, a, i, txtValue;
                        input = document.getElementById("search-input-conversation");
                        filter = input.value.toUpperCase();
                        li = document.getElementsByClassName("robot-search-conversation");
                        for (i = 0; i < li.length; i++) {
                            a = li[i];
                            txtValue = a.textContent || a.innerText;
                            if (txtValue.toUpperCase().indexOf(filter) > -1) {
                                li[i].style.display = "";
                            } else {
                                li[i].style.display = "none";
                            }
                        }
                    },
                    attachEvents = function() {
                        document.querySelectorAll('#send').forEach(button => {
                            button.onclick = function() {
                                sendChat()
                            }
                        });
                        document.getElementById('search-input').addEventListener("keyup", function(event) {
                            searchFilter();
                        });
                        document.getElementById('search-input-conversation').addEventListener("keyup", function(event) {
                            searchFilterConversation();
                        });
                        document.getElementById('message-to-send').addEventListener("keypress", function(event) {
                            if (event.keyCode == 13 && !event.shiftKey && submit_button.disabled == false) {
                                event.preventDefault()
                                sendChat()
                            }
                        });
                    };
                return {
                    init: function() {
                        attachEvents();
                        initShiki()
                        fixChatScroll()
                    }
                }
            }()
            document.addEventListener("DOMContentLoaded", function(event) {
                APP.init();
            });
        </script>
    @endpush
</x-chat-layout>
